@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import cpl
 import os
@@ -35,7 +35,7 @@ Constructor
 
 {parameters}
 
-.. seealso:: `cpl.Recipe <http://packages.python.org/python-cpl/recipe.html>`_
+.. seealso:: `cpl.Recipe <https://packages.python.org/python-cpl/recipe.html>`_
    for more information about the recipe object.
 
 Bug reports
@@ -78,10 +78,10 @@ These pages describe the python interface for the {PIPELINE} pipeline recipes.
      * The `{PIPELINE} Pipeline User Manual 
        <ftp://ftp.eso.org/pub/dfs/pipelines/{pipeline}/{pipeline}-pipeline-cookbook-{version}.pdf>`_ in PDF format,
 
-     * an `overview <http://www.eso.org/sci/software/pipelines/>`_
+     * an `overview <https://www.eso.org/sci/software/pipelines/>`_
        over the existing ESO pipelines,
 
-     * the `python-cpl <http://packages.python.org/python-cpl>`_ package.
+     * the `python-cpl <https://packages.python.org/python-cpl>`_ package.
     
 Bug reports
 ===========
@@ -146,8 +146,7 @@ oca = '\n'.join(
       "muse_focus", "muse_geometry", "muse_create_sky", "muse_standard",
       "muse_astrometry", "muse_scibasic", "muse_scipost", "muse_exp_combine" ])
 recipes_oca = [recipe for recipe in recipes if recipe.__name__ in oca]
-index = [ oca.find(recipe.__name__) for recipe in recipes_oca ]
-recipes_oca = [r for (i, r) in sorted(zip(index, recipes_oca))]
+recipes_oca.sort(key = lambda x: x.__name__)
 
 recipes_x = [recipe for recipe in recipes if not recipe.__name__ in oca]
 recipes_x.sort(key = lambda x: x.__name__)
